MethodChannelFlutterPytorchLite class

PyTorch Lite An implementation of FlutterPytorchLitePlatform that uses method channels.

@author guoweifeng @date 2024/1/10 10:37

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy(int moduleId) → Future<void>
override
forward(int moduleId, List<IValue> inputs) → Future<IValue>
override
load(String filePath) → Future<int>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited